#---------------------------------------------------------------------------
#
#   MWG - Playing screen
#
#---------------------------------------------------------------------------

from pygame import locals as pk
from albow.widget import Widget
from humerus.main_commands import MainCommandScreen
from level_view import LevelView

#---------------------------------------------------------------------------

class MwgPlayScreen(MainCommandScreen):

	def __init__(self, shell):
		MainCommandScreen.__init__(self, shell)
		self.game = self.shell.game
		level_view = LevelView(self.game)
		message_view = MessageView(self)
		message_view.width = self.width
		message_view.topleft = level_view.bottomleft
		self.add(level_view)
		self.add(message_view)
	
	def level(self):
		return self.game.playing_level
	
	def begin_frame(self):
		MainCommandScreen.begin_frame(self)
		self.invalidate()

	def key_down(self, e):
		if e.cmd or e.key == pk.K_ESCAPE:
			MainCommandScreen.key_down(self, e)
		else:
			self.level().key_down(e)

	def key_up(self, e):
		self.level().key_up(e)

#---------------------------------------------------------------------------

class MessageView(Widget):

	margin = 2

	def __init__(self, client):
		Widget.__init__(self)
		self.height = self.font.get_linesize() + 2 * self.margin
		self.client = client
		
	def draw(self, surf):
		level = self.client.level()
		cell = level.cell_containing_player()
		msg = cell.message
		if msg:
			buf = self.font.render(msg, True, self.fg_color)
			frame = self.get_margin_rect()
			surf.blit(buf, frame)
